######
pyNSoT
######

.. image:: https://raw.githubusercontent.com/dropbox/pynsot/master/docs/_static/logo_128.png
   :alt: Network Source of Truth
   :width: 128px

|Build Status| |Documentation Status| |PyPI Status|

.. _Network Source of Truth (NSoT): https://nsot.readthedocs.io

.. |Build Status| image:: https://img.shields.io/travis/dropbox/pynsot/master.svg?style=flat
   :target: https://travis-ci.org/dropbox/pynsot
   :width: 88px
   :height: 20px
.. |Documentation Status| image:: https://readthedocs.org/projects/pynsot/badge/?version=latest&style=flat
   :target: https://readthedocs.io/projects/pynsot/?badge=latest
   :width: 76px
   :height: 20px
.. |PyPI Status| image:: https://img.shields.io/pypi/v/pynsot.svg?style=flat
   :target: https://pypi.python.org/pypi/pynsot
   :width: 68px
   :height: 20px

Python client library and command-line utility for the `Network Source of
Truth <https://github.com/dropbox/nsot>`_ (NSoT) IPAM and source of truth
database REST API.

Read the docs at http://pynsot.readthedocs.io
